## ----setup, include=FALSE---------------------------------
library(knitr)
library(rmarkdown)
options(continue=" ")
options(width=60)
knitr::opts_chunk$set(echo = TRUE,
                      warning = FALSE,
                      message = FALSE)

## ----runApp, eval=FALSE-----------------------------------
#  library(toxEval)
#  explore_endpoints()

## ---------------------------------------------------------
citation(package = "toxEval")

